#!/bin/sh
# *******************************************************************************
#  Licensed Materials - Property of IBM
#  (c) Copyright IBM Corporation 2012. All Rights Reserved.
#
#  Note to U.S. Government Users Restricted Rights:
#  Use, duplication or disclosure restricted by GSA ADP Schedule
#  Contract with IBM Corp.
#  *******************************************************************************

# ################################################################################
#
# File for messages displayed by the upgrade automated scripts.
#
# ################################################################################


# *********************
# * Messages function *
# *********************
messages() {

case $1 in 

# *********************************
# * Initial verification messages *
# *********************************

INVALID_LAUNCH )
echo ""
echo "请勿直接执行 app_upgrade 脚本。要升级应用程序，请运行下列其中一个命令："
echo "    dm_upgrade"
echo "    vvc_upgrade"
echo "请使用 -help 以获取关于上述命令的完整描述。"
;;

INVALID_START_DIR )
echo ""
echo "除了使用 -help 参数之外，无法从 $3 之外的另一个目录来运行 $2 脚本"
echo ""
;;


SHOW_PARAM_FILE_NAME )
echo ""
echo "文件“$2”包含升级脚本的参数值。"
echo "如果您需要修改任何缺省参数值，那么可以编辑这些文件，也可以指定参数值作为升级脚本的命令行参数。"
echo ""
;;

SHOW_PARAM_FILE_NAMES_LIST )
echo ""
echo "下列文件集合包含用于应用程序升级的缺省参数值。如果您需要修改任何缺省参数值，那么可以编辑这些文件，也可以指定参数值作为升级脚本的命令行参数。"
echo "- DM 升级：$2/params/dm_params$3.sh"
echo "- VVC 升级：$2/params/vvc_params$3.sh"
echo ""
;;


# ************************************
# * Parameters verification messages *
# ************************************

# Intrinsic verification
# ======================

MISSING_APP_TYPE )
echo ""
echo "未指定应用程序类型。要升级应用程序，请运行下列其中一个命令："
echo "    dm_upgrade"
echo "    vvc_upgrade"
echo "请使用 -help 以获取关于上述命令的完整描述。"
echo ""
;;

INVALID_APP_TYPE )
echo ""
echo "$2 不是有效的应用程序类型。要升级应用程序，请运行下列其中一个命令："
echo "    dm_upgrade"
echo "    vvc_upgrade"
echo "请使用 -help 以获取关于上述命令的完整描述。"
echo ""
;;

MISSING_PARAM_VALUE )
echo ""
echo "缺少参数 $2 的值。"
echo "请使用 -help 以获取关于参数的完整描述。"
echo ""
;;

INVALID_PARAM_DIR )
echo ""
echo "为参数 $2 指定的目录 $3 不存在或者无效。"
echo "请使用 -help 以获取关于参数的完整描述。"
echo ""
;;

RELATIVE_PARAM_DIR )
echo ""
echo "为参数 $2 指定的目录 $3 必须是一个绝对路径。"
echo "请使用 -help 以获取关于参数的完整描述。"
echo ""
;;

INVALID_PARAM_FILE )
echo ""
echo "为参数 $2 指定的文件 $3 不存在或者无效。"
echo "请使用 -help 以获取关于参数的完整描述。"
echo ""
;;

INVALID_PARAM_VALUE )
echo ""
echo "对于 $2 参数，$3 是无效值。"
echo "请使用 -help 以获取关于参数的完整描述。"
echo ""
;;

INVALID_PARAM )
echo ""
echo "$2 是未知参数。"
echo "请使用 -help 以获取关于参数的完整描述。"
echo ""
;;


# Extrinsic verification
# ======================

MISSING_HOME_PARAM )
echo ""
echo "缺少主目录参数 $2。"
echo "请使用 -help 以获取关于参数的完整描述。"
echo ""
;;

DIR_NOT_FOUND )
echo ""
echo "目录 $2 不存在或无效。"
echo ""
;;

CMD_NOT_FOUND_2X_APP )
echo ""
echo "找不到应用程序 repotools 命令“$2”。"
echo ""
echo "请确认 -oldApplicationHome 参数“$3”指向旧的服务器配置目录，例如，“JazzInstallDir/server/conf”。"
echo ""
;;

CMD_NOT_FOUND_OLD_APP )
echo ""
echo "找不到应用程序 repotools 命令“$2”。"
echo ""
echo "请确认 -oldApplicationHome 参数“$3”指向旧的服务器配置目录（例如，“JazzInstallDir/server/conf”）并且 jtsContextRoot 参数“$4”正确。"
echo ""
;;

TSP_NOT_FOUND_2X_APP )
echo ""
echo "找不到配置文件“$2”。"
echo ""
echo "请确认 -oldApplicationHome 参数“$3”指向旧的服务器配置目录，例如，“JazzInstallDir/server/conf”。"
echo ""
;;

TSP_NOT_FOUND_OLD_APP )
echo ""
echo "找不到配置文件“$2”。"
echo ""
echo "请确认 -oldApplicationHome 参数“$3”指向旧的服务器配置目录（例如，“JazzInstallDir/server/conf”）并且 jtsContextRoot 参数“$4”正确。"
echo ""
;;

CMD_NOT_FOUND_NEW_APP )
echo ""
echo "找不到应用程序 repotools 命令“$2”。"
echo ""
echo "请确认 -newApplicationHome 参数“$3”指向新的服务器配置目录（例如，“JazzInstallDir/server/conf”）并且 jtsContextRoot 参数“$4”正确。"
echo "如果您正在从先前发行版进行升级，请确保您选择的上下文根正确。例如，如果正在使用 Installation Manager，那么必须在“上下文根选项”面板上选择 $5 上下文根选项。如果偶然选择了其他选项，那么必须使用 $5 上下文根选项重新安装产品。"
echo ""
;;

TSP_NOT_FOUND_NEW_APP )
echo ""
echo "找不到配置文件“$2”。"
echo ""
echo "请确认 -newApplicationHome 参数“$3”指向新的 JTS 服务器配置目录（例如，“JazzInstallDir/server/conf”）并且 jtsContextRoot 参数“$4”正确。"
echo "如果您正在从先前发行版进行升级，请确保您选择的上下文根正确。例如，如果正在使用 Installation Manager，那么必须在“上下文根选项”面板上选择 $5 上下文根选项。如果偶然选择了其他选项，那么必须使用 $5 上下文根选项重新安装产品。"
echo ""
;;

CMD_NOT_FOUND_OLD_JTS )
echo ""
echo "找不到 JTS repotools 命令“$2”。"
echo ""
echo "请确认 -oldJTSHome 参数“$3”指向旧的 JTS 服务器配置目录（例如，“JazzInstallDir/server/conf”）并且 jtsContextRoot 参数“$4”正确。"
echo ""
;;

TSP_NOT_FOUND_OLD_JTS )
echo ""
echo "找不到配置文件“$2”。"
echo ""
echo "请确认 -oldJTSHome 参数“$3”指向旧的 JTS 服务器配置目录（例如，“JazzInstallDir/server/conf”）并且 jtsContextRoot 参数“$4”正确。"
echo ""
;;

CMD_NOT_FOUND_NEW_JTS )
echo ""
echo "找不到 JTS repotools 命令“$2”。"
echo ""
echo "请确认 -newJTSHome 参数“$3”指向新的 JTS 服务器配置目录（例如，“JazzInstallDir/server/conf”）并且 jtsContextRoot 参数“$4”正确。"
echo ""
;;

TSP_NOT_FOUND_NEW_JTS )
echo ""
echo "找不到配置文件“$2”。"
echo ""
echo "请确认 -newJTSHome 参数“$3”指向新的 JTS 服务器配置目录（例如，“JazzInstallDir/server/conf”）并且 jtsContextRoot 参数“$4”正确。"
echo ""
;;

MISSING_IMPORT_FROM_FILE )
echo ""
echo "需要具备包含 2.x 数据的 tar 文件才能进行 $2 升级。"
echo "请使用 -help 以获取关于参数的完整描述。"
echo ""
;;


# **********************
# * Execution messages *
# **********************

BANNER_dm )
echo ""
echo ""
echo "============================================="
echo "===    DM 升级    ==="
echo "============================================="
echo ""
;;

BANNER_vvc )
echo ""
echo ""
echo "============================================"
echo "===    VVC 升级    ==="
echo "============================================"
echo ""
;;


# *********************
# * First step switch *
# *********************

INITIAL_STEP_FAILED )
echo ""
echo "最后一次执行时在初始步骤失败..."
;;

LAST_STEP_FAILED )
echo ""
echo "最后一次执行时在步骤 $2 失败..."
echo "要重新开始从此步骤或前一步骤进行升级吗？"
;;

ALREADY_RUN )
echo ""
echo "已进行升级并且已成功完成..."
echo "要从特定步骤重新开始新的升级吗？"
;;

LAST_STEP_PASSED )
echo ""
echo "最后一次执行时在步骤 $2 成功停止..."
echo "要重新开始从当前步骤 $3 或前一步骤进行升级吗？"
;;

ENTER_NEXT_STEP )
echo ""
echo "请输入您想要从其重新开始进行升级的步骤编号 [$2-$3]，或者按 [Enter] 键以取消："
;;

INTEGER_STEP_NUMBER )
echo ""
echo "“$2”不是数字。请输入有效步骤编号。"
;;

INVALID_STEP_NUMBER )
echo ""
echo "“$2”是无效的步骤编号。请输入有效步骤编号。"
;;

MAX_STEP_NUMBER )
echo ""
echo "最后一个步骤是步骤 $2，因此您不能从步骤 $3 重新开始进行升级。"
;;

NUM_MAX_STEP_NUMBER )
echo ""
echo "步骤 $2 尚未运行，因此您不能从步骤 $3 重新开始进行升级。"
;;


# **********************
# * Messages for Steps *
# **********************

STEP_0_IBMi )
echo "步骤 0：删除表"
echo "-------------------"
;;

STEP_0 )
echo "步骤 0：更新配置文件"
echo "---------------------------"
;;

STEP_1_ADD )
echo "步骤 1：添加表"
echo "------------------"
;;

FULL_TEXT_INDICES_STEP )
echo "步骤 $2：重新构建文本索引"
echo "----------------------------"
;;

JFS_INDICES_STEP )
echo "步骤 $2：重新创建查询和搜索索引"
echo "-----------------------------------------"
;;

STEP_2_UPGRADE_DATA_WAREHOUSE )
echo "步骤 2：升级数据仓库模式"
echo "-------------------------------------"
;;

OVERALL_MIGRATION_FAILED )
echo ""
echo "$2 升级在步骤 $3 失败。请解决问题，然后从步骤 $3 开始再次运行此脚本。"
echo "" 
;;

OVERALL_MIGRATION_SUCCESS_DM )
echo ""
echo "$2 升级已成功。如果您也升级了 JTS 和 VVC，那么您现在可以启动部署中的服务器。"
echo ""
;;

OVERALL_MIGRATION_SUCCESS_VVC )
echo ""
echo "$2 升级已成功。如果您也升级了 JTS 和任何从属应用程序（如 DM），那么您现在可以启动部署中的服务器。"
echo ""
;;

# *******************************
# * Messages while running step *
# *******************************

STEP_DIR_CMD )
echo ""
echo "目录：$2"
echo "命令："
;;

ENTER_STEP_ACTION )
echo "输入 [E] 以执行此步骤，输入 [S] 以跳过此步骤，或者按 [Enter] 以取消执行脚本："
;;

INVALID_STEP_ACTION )
echo ""
echo "“$2”是无效条目，只允许为“E”、“S”或“Enter”"
echo ""
;;

EDIT_TEAMSERVER_PROPERTIES )
echo ""
echo "将打开一个 vi 编辑器，以允许您验证 $2 teamserver.properties 文件。"
echo "请确认 com.ibm.team.repository.server.webapp.url 属性所指定的公用 URI 根正确。"
echo "请确认数据库属性正确。"
echo "完成后，请保存变更（如果有）并关闭编辑器以继续执行脚本。"
echo ""
;;

PAUSE )
echo ""
echo "请输入 [C] 以继续执行，或者按 [Enter] 键以取消执行此脚本："
;;

INVALID_PAUSE_ACTION )
echo ""
echo "“$2”是无效条目，只允许为“C”或“Enter”"
echo ""
;;

COPY_INDICES_FAILED )
echo ""
echo "未能将文本索引从“$2”复制到“$3”。"
echo "请验证在 teamserver.properties 文件中定义"
echo "的 com.ibm.team.fulltext.indexLocation 属性。"
echo "手动将文本索引复制到此目录"
echo "或者运行 repotools -rebuildTextIndices 以重新构建文本索引。"
echo ""
;;

# *****************************************
# * Messages for Public URIs verification *
# *****************************************

MISSING_PUBLIC_URI )
echo ""
echo ""
echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!! 错误 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
echo ""
echo "在 $3 中未定义任何"
echo "公用 URI，"
echo "因此，无法开始进行升级。"
echo ""
echo "此文件中必须有一个按如下所示定义的公用 URI："
echo "https\://hostname.example.com\:port/$2"
echo ""
echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
echo ""
echo "teamserver.properties 文件中必须存在公用 URI 属性 com.ibm.team.repository.server.webapp.url。"
echo "将此属性添加至旧安装的 teamserver.properties 文件，并将值设置为所有客户机用来访问服务器的 URI 根。"
echo "公用 URI 根对于新安装的正常运行非常重要。如果没有此属性，那么升级将不会成功。"
echo "有关更多信息，请参阅信息中心中有关“规划 URI”的主题。"
echo ""
;;

COMMENTED_PUBLIC_URI )
echo ""
echo ""
echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!! 错误 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
echo ""
echo "已将 $3 中定义的所有公用 URI 注释"
echo "掉，"
echo "因此，无法开始进行升级。"
echo ""
echo "此文件中应当有一个按如下所示定义且已取消注释的公用 URI："
echo "https/://hostname.example.com/:port/$2"
echo ""
echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
echo ""
echo "teamserver.properties 文件中必须存在公用 URI 属性 com.ibm.team.repository.server.webapp.url。"
echo "将此属性添加至旧安装的 teamserver.properties 文件，并将值设置为所有客户机用来访问服务器的 URI 根。"
echo "公用 URI 根对于新安装的正常运行非常重要。如果没有此属性，那么升级将不会成功。"
echo "有关更多信息，请参阅信息中心中有关“规划 URI”的主题。"
echo ""
;;

CONTEXT_ROOTS_CANNOT_BE_EQUAL )
echo ""
echo "JTS 的上下文根设置为“$2”。"
echo "应用程序的上下文根设置为“$3”。"
echo "JTS 和应用程序的上下文根不得相同。"
echo ""
;;

esac

}
